/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */
package org.greenstone.gatherer.cdm;
/**************************************************************************************
 * Written:      20/05/02
 * Revised:      03/07/03
 **************************************************************************************/
import java.util.ArrayList;
/** This class provides an interface to any class that contains a list of Arguments.
 * @author John Thompson, Greenstone Digital Library, University of Waikato
 * @version 2.3
 */
public interface ArgumentContainer {
    /** Method to retrieve the list of arguments from this container. Note that this method returns both the containers arguments plus its 'supers' arguments if any, and alphabetically orders them.
     * @param include_normal true to filter so normal arguments are returned
     * @param include_custom true to filter so custom arguments are returned
     * @return the arguments within a ArrayList
     */
    public ArrayList getArguments(boolean include_normal, boolean include_custom);
    /** Method to retrieve this containers custom argument string.
     * @return the custom arguments as a String
     */
    public String getCustom();
    /** Method to retrieve the name associated with this argument container.
     * @return the name as a String
     */
    public String getName();
    /** Method to set the custom arguments string.
     * @param custom the new custom argument String
     */
    public void setCustom(String custom);
}





